import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class Main {

    static class Customer {
        String name;
        String address;
        String contactPerson;
        boolean taxExempt;
        boolean smallBusiness;

        Customer(String name, String address, String contactPerson, boolean taxExempt, boolean smallBusiness) {
            this.name = name;
            this.address = address;
            this.contactPerson = contactPerson;
            this.taxExempt = taxExempt;
            this.smallBusiness = smallBusiness;
        }
    }

    static class Article {
        static int nextId = 1;
        int id;
        String unit;
        String description;
        double netPrice;
        double vatRate;

        Article(String unit, String description, double netPrice, double vatRate) {
            this.id = nextId++;
            this.unit = unit;
            this.description = description;
            this.netPrice = netPrice;
            this.vatRate = vatRate;
        }
    }

    static class Offer {
        int id;
        Customer customer;
        List<Article> articles;
        String date;
        String status;

        Offer(int id, Customer customer, List<Article> articles, String date, String status) {
            this.id = id;
            this.customer = customer;
            this.articles = articles;
            this.date = date;
            this.status = status;
        }
    }

    static class OrderConfirmation {
        int id;
        Offer offer;
        String date;
        String status;

        OrderConfirmation(int id, Offer offer, String date, String status) {
            this.id = id;
            this.offer = offer;
            this.date = date;
            this.status = status;
        }
    }

    static class DeliveryNote {
        int id;
        OrderConfirmation orderConfirmation;
        String date;
        String status;

        DeliveryNote(int id, OrderConfirmation orderConfirmation, String date, String status) {
            this.id = id;
            this.orderConfirmation = orderConfirmation;
            this.date = date;
            this.status = status;
        }
    }

    static class Invoice {
        int id;
        DeliveryNote deliveryNote;
        String date;
        String status;

        Invoice(int id, DeliveryNote deliveryNote, String date, String status) {
            this.id = id;
            this.deliveryNote = deliveryNote;
            this.date = date;
            this.status = status;
        }
    }

    static List<Customer> customers = new ArrayList<>();
    static List<Article> articles = new ArrayList<>();
    static List<Offer> offers = new ArrayList<>();
    static List<OrderConfirmation> orderConfirmations = new ArrayList<>();
    static List<DeliveryNote> deliveryNotes = new ArrayList<>();
    static List<Invoice> invoices = new ArrayList<>();
    private static Scanner scanner = new Scanner(System.in);
    static int nextOfferId = 1;
    static int nextOrderConfirmationId = 1;
    static int nextDeliveryNoteId = 1;
    static int nextInvoiceId = 1;

    public static void main(String[] args) {
        while (true) {
            System.out.println("1. Kunde hinzufügen");
            System.out.println("2. Kunden anzeigen");
            System.out.println("3. Artikel hinzufügen");
            System.out.println("4. Artikel anzeigen");
            System.out.println("5. Angebot erstellen");
            System.out.println("6. Angebote anzeigen");
            System.out.println("7. Auftragsbestätigung erstellen");
            System.out.println("8. Auftragsbestätigungen anzeigen");
            System.out.println("9. Lieferschein erstellen");
            System.out.println("10. Lieferscheine anzeigen");
            System.out.println("11. Rechnung erstellen");
            System.out.println("12. Rechnungen anzeigen");
            System.out.println("13. Daten speichern");
            System.out.println("14. Daten laden");
            System.out.println("15. Beenden");
            System.out.print("Wählen Sie eine Option: ");
            int choice = scanner.nextInt();
            scanner.nextLine(); // consume newline

            switch (choice) {
                case 1:
                    addCustomer();
                    break;
                case 2:
                    displayCustomers();
                    break;
                case 3:
                    addArticle();
                    break;
                case 4:
                    displayArticles();
                    break;
                case 5:
                    createOffer();
                    break;
                case 6:
                    displayOffers();
                    break;
                case 7:
                    createOrderConfirmation();
                    break;
                case 8:
                    displayOrderConfirmations();
                    break;
                case 9:
                    createDeliveryNote();
                    break;
                case 10:
                    displayDeliveryNotes();
                    break;
                case 11:
                    createInvoice();
                    break;
                case 12:
                    displayInvoices();
                    break;
                case 13:
                    saveData();
                    break;
                case 14:
                    loadData();
                    break;
                case 15:
                    System.exit(0);
                    break;
                default:
                    System.out.println("Ungültige Option. Bitte versuchen Sie es erneut.");
            }
        }
    }

    private static void addCustomer() {
        System.out.print("Kundenname: ");
        String name = scanner.nextLine();
        System.out.print("Adresse: ");
        String address = scanner.nextLine();
        System.out.print("Ansprechpartner: ");
        String contactPerson = scanner.nextLine();
        System.out.print("Fällt der Kunde unter § 4 Umsatzsteuergesetz (ja/nein): ");
        boolean taxExempt = scanner.nextLine().equalsIgnoreCase("ja");
        System.out.print("Kleinunternehmer (ja/nein): ");
        boolean smallBusiness = scanner.nextLine().equalsIgnoreCase("ja");

        customers.add(new Customer(name, address, contactPerson, taxExempt, smallBusiness));
    }

    private static void displayCustomers() {
        if (customers.isEmpty()) {
            System.out.println("Keine Kunden vorhanden.");
        } else {
            for (Customer customer : customers) {
                System.out.println("Name: " + customer.name);
                System.out.println("Adresse: " + customer.address);
                System.out.println("Ansprechpartner: " + customer.contactPerson);
                System.out.println("Unter § 4 UStG: " + (customer.taxExempt ? "Ja" : "Nein"));
                System.out.println("Kleinunternehmer: " + (customer.smallBusiness ? "Ja" : "Nein"));
                System.out.println();
            }
        }
    }

    private static void addArticle() {
        System.out.print("Einheit: ");
        String unit = scanner.nextLine();
        System.out.print("Bezeichnung: ");
        String description = scanner.nextLine();
        System.out.print("Nettopreis: ");
        double netPrice = scanner.nextDouble();
        System.out.print("Mehrwertsteuersatz: ");
        double vatRate = scanner.nextDouble();
        scanner.nextLine(); // consume newline

        articles.add(new Article(unit, description, netPrice, vatRate));
    }

    private static void displayArticles() {
        if (articles.isEmpty()) {
            System.out.println("Keine Artikel vorhanden.");
        } else {
            for (Article article : articles) {
                System.out.println("Artikelnummer: " + article.id);
                System.out.println("Einheit: " + article.unit);
                System.out.println("Bezeichnung: " + article.description);
                System.out.println("Nettopreis: " + article.netPrice);
                System.out.println("Mehrwertsteuersatz: " + article.vatRate);
                System.out.println();
            }
        }
    }

    private static void createOffer() {
        if (customers.isEmpty() || articles.isEmpty()) {
            System.out.println("Es müssen zuerst Kunden und Artikel angelegt werden.");
            return;
        }

        System.out.println("Wählen Sie einen Kunden aus:");
        for (int i = 0; i < customers.size(); i++) {
            System.out.println((i + 1) + ". " + customers.get(i).name);
        }
        System.out.print("Kundennummer: ");
        int customerIndex = scanner.nextInt() - 1;
        scanner.nextLine(); // consume newline

        if (customerIndex < 0 || customerIndex >= customers.size()) {
            System.out.println("Ungültige Kundennummer.");
            return;
        }

        Customer selectedCustomer = customers.get(customerIndex);
        List<Article> selectedArticles = new ArrayList<>();

        while (true) {
            System.out.println("Wählen Sie einen Artikel aus (0 zum Beenden):");
            for (int i = 0; i < articles.size(); i++) {
                System.out.println((i + 1) + ". " + articles.get(i).description);
            }
            System.out.print("Artikelnummer: ");
            int articleIndex = scanner.nextInt() - 1;
            scanner.nextLine(); // consume newline

            if (articleIndex == -1) break;
            if (articleIndex < 0 || articleIndex >= articles.size()) {
                System.out.println("Ungültige Artikelnummer.");
                continue;
            }

            selectedArticles.add(articles.get(articleIndex));
        }

        System.out.print("Datum des Angebots (z.B. 2024-06-30): ");
        String date = scanner.nextLine();

        offers.add(new Offer(nextOfferId++, selectedCustomer, selectedArticles, date, "Angebot erstellt"));
        System.out.println("Angebot erfolgreich erstellt.");
    }

    private static void displayOffers() {
        if (offers.isEmpty()) {
            System.out.println("Keine Angebote vorhanden.");
        } else {
            for (Offer offer : offers) {
                System.out.println("Angebotsnummer: " + offer.id);
                System.out.println("Kunde: " + offer.customer.name);
                System.out.println("Datum: " + offer.date);
                System.out.println("Status: " + offer.status);
                System.out.println("Artikel:");
                for (Article article : offer.articles) {
                    System.out.println("- " + article.description + " (Einheit: " + article.unit + ", Nettopreis: " + article.netPrice + ", MwSt.: " + article.vatRate + ")");
                }
                System.out.println();
            }
        }
    }

    private static void createOrderConfirmation() {
        if (offers.isEmpty()) {
            System.out.println("Es müssen zuerst Angebote erstellt werden.");
            return;
        }

        System.out.println("Wählen Sie ein Angebot aus:");
        for (int i = 0; i < offers.size(); i++) {
            System.out.println((i + 1) + ". Angebot #" + offers.get(i).id + " - Kunde: " + offers.get(i).customer.name);
        }
        System.out.print("Angebotsnummer: ");
        int offerIndex = scanner.nextInt() - 1;
        scanner.nextLine(); // consume newline

        if (offerIndex < 0 || offerIndex >= offers.size()) {
            System.out.println("Ungültige Angebotsnummer.");
            return;
        }

        Offer selectedOffer = offers.get(offerIndex);

        System.out.print("Datum der Auftragsbestätigung (z.B. 2024-06-30): ");
        String date = scanner.nextLine();

        orderConfirmations.add(new OrderConfirmation(nextOrderConfirmationId++, selectedOffer, date, "Auftragsbestätigung erstellt"));
        selectedOffer.status = "Auftragsbestätigung erstellt";
        System.out.println("Auftragsbestätigung erfolgreich erstellt.");
    }

    private static void displayOrderConfirmations() {
        if (orderConfirmations.isEmpty()) {
            System.out.println("Keine Auftragsbestätigungen vorhanden.");
        } else {
            for (OrderConfirmation orderConfirmation : orderConfirmations) {
                System.out.println("Auftragsbestätigungsnummer: " + orderConfirmation.id);
                System.out.println("Angebotsnummer: " + orderConfirmation.offer.id);
                System.out.println("Kunde: " + orderConfirmation.offer.customer.name);
                System.out.println("Datum: " + orderConfirmation.date);
                System.out.println("Status: " + orderConfirmation.status);
                System.out.println();
            }
        }
    }

    private static void createDeliveryNote() {
        if (orderConfirmations.isEmpty()) {
            System.out.println("Es müssen zuerst Auftragsbestätigungen erstellt werden.");
            return;
        }

        System.out.println("Wählen Sie eine Auftragsbestätigung aus:");
        for (int i = 0; i < orderConfirmations.size(); i++) {
            System.out.println((i + 1) + ". Auftragsbestätigung #" + orderConfirmations.get(i).id + " - Kunde: " + orderConfirmations.get(i).offer.customer.name);
        }
        System.out.print("Auftragsbestätigungsnummer: ");
        int orderConfirmationIndex = scanner.nextInt() - 1;
        scanner.nextLine(); // consume newline

        if (orderConfirmationIndex < 0 || orderConfirmationIndex >= orderConfirmations.size()) {
            System.out.println("Ungültige Auftragsbestätigungsnummer.");
            return;
        }

        OrderConfirmation selectedOrderConfirmation = orderConfirmations.get(orderConfirmationIndex);

        System.out.print("Datum des Lieferscheins (z.B. 2024-06-30): ");
        String date = scanner.nextLine();

        deliveryNotes.add(new DeliveryNote(nextDeliveryNoteId++, selectedOrderConfirmation, date, "Lieferschein erstellt"));
        selectedOrderConfirmation.status = "Lieferschein erstellt";
        selectedOrderConfirmation.offer.status = "Lieferschein erstellt";
        System.out.println("Lieferschein erfolgreich erstellt.");
    }

    private static void displayDeliveryNotes() {
        if (deliveryNotes.isEmpty()) {
            System.out.println("Keine Lieferscheine vorhanden.");
        } else {
            for (DeliveryNote deliveryNote : deliveryNotes) {
                System.out.println("Lieferscheinnummer: " + deliveryNote.id);
                System.out.println("Auftragsbestätigungsnummer: " + deliveryNote.orderConfirmation.id);
                System.out.println("Kunde: " + deliveryNote.orderConfirmation.offer.customer.name);
                System.out.println("Datum: " + deliveryNote.date);
                System.out.println("Status: " + deliveryNote.status);
                System.out.println();
            }
        }
    }

    private static void createInvoice() {
        if (deliveryNotes.isEmpty()) {
            System.out.println("Es müssen zuerst Lieferscheine erstellt werden.");
            return;
        }

        System.out.println("Wählen Sie einen Lieferschein aus:");
        for (int i = 0; i < deliveryNotes.size(); i++) {
            System.out.println((i + 1) + ". Lieferschein #" + deliveryNotes.get(i).id + " - Kunde: " + deliveryNotes.get(i).orderConfirmation.offer.customer.name);
        }
        System.out.print("Lieferscheinnummer: ");
        int deliveryNoteIndex = scanner.nextInt() - 1;
        scanner.nextLine(); // consume newline

        if (deliveryNoteIndex < 0 || deliveryNoteIndex >= deliveryNotes.size()) {
            System.out.println("Ungültige Lieferscheinnummer.");
            return;
        }

        DeliveryNote selectedDeliveryNote = deliveryNotes.get(deliveryNoteIndex);

        System.out.print("Datum der Rechnung (z.B. 2024-06-30): ");
        String date = scanner.nextLine();

        invoices.add(new Invoice(nextInvoiceId++, selectedDeliveryNote, date, "Rechnung erstellt"));
        selectedDeliveryNote.status = "Rechnung erstellt";
        selectedDeliveryNote.orderConfirmation.status = "Rechnung erstellt";
        selectedDeliveryNote.orderConfirmation.offer.status = "Rechnung erstellt";
        System.out.println("Rechnung erfolgreich erstellt.");
    }

    private static void displayInvoices() {
        if (invoices.isEmpty()) {
            System.out.println("Keine Rechnungen vorhanden.");
        } else {
            for (Invoice invoice : invoices) {
                System.out.println("Rechnungsnummer: " + invoice.id);
                System.out.println("Lieferscheinnummer: " + invoice.deliveryNote.id);
                System.out.println("Kunde: " + invoice.deliveryNote.orderConfirmation.offer.customer.name);
                System.out.println("Datum: " + invoice.date);
                System.out.println("Status: " + invoice.status);
                System.out.println();
            }
        }
    }

    static void saveData() {
        try {
            DocumentBuilderFactory documentFactory = DocumentBuilderFactory.newInstance();
            DocumentBuilder documentBuilder = documentFactory.newDocumentBuilder();
            Document document = documentBuilder.newDocument();

            Element root = document.createElement("Fakturama");
            document.appendChild(root);

            Element customersElement = document.createElement("Customers");
            root.appendChild(customersElement);

            for (Customer customer : customers) {
                Element customerElement = document.createElement("Customer");

                Element name = document.createElement("Name");
                name.appendChild(document.createTextNode(customer.name));
                customerElement.appendChild(name);

                Element address = document.createElement("Address");
                address.appendChild(document.createTextNode(customer.address));
                customerElement.appendChild(address);

                Element contactPerson = document.createElement("ContactPerson");
                contactPerson.appendChild(document.createTextNode(customer.contactPerson));
                customerElement.appendChild(contactPerson);

                Element taxExempt = document.createElement("TaxExempt");
                taxExempt.appendChild(document.createTextNode(Boolean.toString(customer.taxExempt)));
                customerElement.appendChild(taxExempt);

                Element smallBusiness = document.createElement("SmallBusiness");
                smallBusiness.appendChild(document.createTextNode(Boolean.toString(customer.smallBusiness)));
                customerElement.appendChild(smallBusiness);

                customersElement.appendChild(customerElement);
            }

            Element articlesElement = document.createElement("Articles");
            root.appendChild(articlesElement);

            for (Article article : articles) {
                Element articleElement = document.createElement("Article");

                Element id = document.createElement("ID");
                id.appendChild(document.createTextNode(Integer.toString(article.id)));
                articleElement.appendChild(id);

                Element unit = document.createElement("Unit");
                unit.appendChild(document.createTextNode(article.unit));
                articleElement.appendChild(unit);

                Element description = document.createElement("Description");
                description.appendChild(document.createTextNode(article.description));
                articleElement.appendChild(description);

                Element netPrice = document.createElement("NetPrice");
                netPrice.appendChild(document.createTextNode(Double.toString(article.netPrice)));
                articleElement.appendChild(netPrice);

                Element vatRate = document.createElement("VatRate");
                vatRate.appendChild(document.createTextNode(Double.toString(article.vatRate)));
                articleElement.appendChild(vatRate);

                articlesElement.appendChild(articleElement);
            }

            Element offersElement = document.createElement("Offers");
            root.appendChild(offersElement);

            for (Offer offer : offers) {
                Element offerElement = document.createElement("Offer");

                Element id = document.createElement("ID");
                id.appendChild(document.createTextNode(Integer.toString(offer.id)));
                offerElement.appendChild(id);

                Element customerName = document.createElement("CustomerName");
                customerName.appendChild(document.createTextNode(offer.customer.name));
                offerElement.appendChild(customerName);

                Element date = document.createElement("Date");
                date.appendChild(document.createTextNode(offer.date));
                offerElement.appendChild(date);

                Element status = document.createElement("Status");
                status.appendChild(document.createTextNode(offer.status));
                offerElement.appendChild(status);

                Element offerArticles = document.createElement("Articles");
                offerElement.appendChild(offerArticles);

                for (Article article : offer.articles) {
                    Element articleElement = document.createElement("Article");

                    Element articleId = document.createElement("ID");
                    articleId.appendChild(document.createTextNode(Integer.toString(article.id)));
                    articleElement.appendChild(articleId);

                    offerArticles.appendChild(articleElement);
                }

                offersElement.appendChild(offerElement);
            }

            Element orderConfirmationsElement = document.createElement("OrderConfirmations");
            root.appendChild(orderConfirmationsElement);

            for (OrderConfirmation orderConfirmation : orderConfirmations) {
                Element orderConfirmationElement = document.createElement("OrderConfirmation");

                Element id = document.createElement("ID");
                id.appendChild(document.createTextNode(Integer.toString(orderConfirmation.id)));
                orderConfirmationElement.appendChild(id);

                Element offerId = document.createElement("OfferID");
                offerId.appendChild(document.createTextNode(Integer.toString(orderConfirmation.offer.id)));
                orderConfirmationElement.appendChild(offerId);

                Element date = document.createElement("Date");
                date.appendChild(document.createTextNode(orderConfirmation.date));
                orderConfirmationElement.appendChild(date);

                Element status = document.createElement("Status");
                status.appendChild(document.createTextNode(orderConfirmation.status));
                orderConfirmationElement.appendChild(status);

                orderConfirmationsElement.appendChild(orderConfirmationElement);
            }

            Element deliveryNotesElement = document.createElement("DeliveryNotes");
            root.appendChild(deliveryNotesElement);

            for (DeliveryNote deliveryNote : deliveryNotes) {
                Element deliveryNoteElement = document.createElement("DeliveryNote");

                Element id = document.createElement("ID");
                id.appendChild(document.createTextNode(Integer.toString(deliveryNote.id)));
                deliveryNoteElement.appendChild(id);

                Element orderConfirmationId = document.createElement("OrderConfirmationID");
                orderConfirmationId.appendChild(document.createTextNode(Integer.toString(deliveryNote.orderConfirmation.id)));
                deliveryNoteElement.appendChild(orderConfirmationId);

                Element date = document.createElement("Date");
                date.appendChild(document.createTextNode(deliveryNote.date));
                deliveryNoteElement.appendChild(date);

                Element status = document.createElement("Status");
                status.appendChild(document.createTextNode(deliveryNote.status));
                deliveryNoteElement.appendChild(status);

                deliveryNotesElement.appendChild(deliveryNoteElement);
            }

            Element invoicesElement = document.createElement("Invoices");
            root.appendChild(invoicesElement);

            for (Invoice invoice : invoices) {
                Element invoiceElement = document.createElement("Invoice");

                Element id = document.createElement("ID");
                id.appendChild(document.createTextNode(Integer.toString(invoice.id)));
                invoiceElement.appendChild(id);

                Element deliveryNoteId = document.createElement("DeliveryNoteID");
                deliveryNoteId.appendChild(document.createTextNode(Integer.toString(invoice.deliveryNote.id)));
                invoiceElement.appendChild(deliveryNoteId);

                Element date = document.createElement("Date");
                date.appendChild(document.createTextNode(invoice.date));
                invoiceElement.appendChild(date);

                Element status = document.createElement("Status");
                status.appendChild(document.createTextNode(invoice.status));
                invoiceElement.appendChild(status);

                invoicesElement.appendChild(invoiceElement);
            }

            TransformerFactory transformerFactory = TransformerFactory.newInstance();
            Transformer transformer = transformerFactory.newTransformer();
            transformer.setOutputProperty(OutputKeys.INDENT, "yes");
            DOMSource domSource = new DOMSource(document);
            StreamResult streamResult = new StreamResult("fakturama_data.xml");

            transformer.transform(domSource, streamResult);

            System.out.println("Daten erfolgreich gespeichert.");

        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    static void loadData() {
        try {
            File xmlFile = new File("fakturama_data.xml");
            if (!xmlFile.exists()) {
                System.out.println("Keine Daten zum Laden vorhanden.");
                return;
            }

            DocumentBuilderFactory documentFactory = DocumentBuilderFactory.newInstance();
            DocumentBuilder documentBuilder = documentFactory.newDocumentBuilder();
            Document document = documentBuilder.parse(xmlFile);
            document.getDocumentElement().normalize();

            NodeList customerList = document.getElementsByTagName("Customer");
            customers.clear(); // Vor dem Laden die aktuelle Liste leeren

            for (int i = 0; i < customerList.getLength(); i++) {
                Node customerNode = customerList.item(i);

                if (customerNode != null && customerNode.getNodeType() == Node.ELEMENT_NODE) {
                    Element customerElement = (Element) customerNode;

                    String name = getElementTextContent(customerElement, "Name");
                    String address = getElementTextContent(customerElement, "Address");
                    String contactPerson = getElementTextContent(customerElement, "ContactPerson");
                    boolean taxExempt = Boolean.parseBoolean(getElementTextContent(customerElement, "TaxExempt"));
                    boolean smallBusiness = Boolean.parseBoolean(getElementTextContent(customerElement, "SmallBusiness"));

                    customers.add(new Customer(name, address, contactPerson, taxExempt, smallBusiness));
                }
            }

            NodeList articleList = document.getElementsByTagName("Article");
            articles.clear(); // Vor dem Laden die aktuelle Liste leeren

            for (int i = 0; i < articleList.getLength(); i++) {
                Node articleNode = articleList.item(i);

                if (articleNode != null && articleNode.getNodeType() == Node.ELEMENT_NODE) {
                    Element articleElement = (Element) articleNode;

                    int id = parseIntOrDefault(getElementTextContent(articleElement, "ID"), -1);
                    String unit = getElementTextContent(articleElement, "Unit");
                    String description = getElementTextContent(articleElement, "Description");
                    double netPrice = parseDoubleOrDefault(getElementTextContent(articleElement, "NetPrice"), 0.0);
                    double vatRate = parseDoubleOrDefault(getElementTextContent(articleElement, "VatRate"), 0.0);

                    Article article = new Article(unit, description, netPrice, vatRate);
                    article.id = id; // Set the ID explicitly
                    articles.add(article);
                }
            }

            NodeList offerList = document.getElementsByTagName("Offer");
            offers.clear(); // Vor dem Laden die aktuelle Liste leeren

            for (int i = 0; i < offerList.getLength(); i++) {
                Node offerNode = offerList.item(i);

                if (offerNode != null && offerNode.getNodeType() == Node.ELEMENT_NODE) {
                    Element offerElement = (Element) offerNode;

                    int id = parseIntOrDefault(getElementTextContent(offerElement, "ID"), -1);
                    String customerName = getElementTextContent(offerElement, "CustomerName");
                    Customer offerCustomer = customers.stream().filter(c -> c.name.equals(customerName)).findFirst().orElse(null);

                    String date = getElementTextContent(offerElement, "Date");
                    String status = getElementTextContent(offerElement, "Status");

                    NodeList offerArticles = offerElement.getElementsByTagName("Article");
                    List<Article> offerArticleList = new ArrayList<>();

                    for (int j = 0; j < offerArticles.getLength(); j++) {
                        Node offerArticleNode = offerArticles.item(j);

                        if (offerArticleNode != null && offerArticleNode.getNodeType() == Node.ELEMENT_NODE) {
                            Element offerArticleElement = (Element) offerArticleNode;

                            int articleId = parseIntOrDefault(getElementTextContent(offerArticleElement, "ID"), -1);
                            Article offerArticle = articles.stream().filter(a -> a.id == articleId).findFirst().orElse(null);

                            if (offerArticle != null) {
                                offerArticleList.add(offerArticle);
                            }
                        }
                    }

                    if (offerCustomer != null) {
                        offers.add(new Offer(id, offerCustomer, offerArticleList, date, status));
                    }
                }
            }

            NodeList orderConfirmationList = document.getElementsByTagName("OrderConfirmation");
            orderConfirmations.clear(); // Vor dem Laden die aktuelle Liste leeren

            for (int i = 0; i < orderConfirmationList.getLength(); i++) {
                Node orderConfirmationNode = orderConfirmationList.item(i);

                if (orderConfirmationNode != null && orderConfirmationNode.getNodeType() == Node.ELEMENT_NODE) {
                    Element orderConfirmationElement = (Element) orderConfirmationNode;

                    int id = parseIntOrDefault(getElementTextContent(orderConfirmationElement, "ID"), -1);
                    int offerId = parseIntOrDefault(getElementTextContent(orderConfirmationElement, "OfferID"), -1);
                    Offer orderConfirmationOffer = offers.stream().filter(o -> o.id == offerId).findFirst().orElse(null);

                    String date = getElementTextContent(orderConfirmationElement, "Date");
                    String status = getElementTextContent(orderConfirmationElement, "Status");

                    if (orderConfirmationOffer != null) {
                        orderConfirmations.add(new OrderConfirmation(id, orderConfirmationOffer, date, status));
                    }
                }
            }

            NodeList deliveryNoteList = document.getElementsByTagName("DeliveryNote");
            deliveryNotes.clear(); // Vor dem Laden die aktuelle Liste leeren

            for (int i = 0; i < deliveryNoteList.getLength(); i++) {
                Node deliveryNoteNode = deliveryNoteList.item(i);

                if (deliveryNoteNode != null && deliveryNoteNode.getNodeType() == Node.ELEMENT_NODE) {
                    Element deliveryNoteElement = (Element) deliveryNoteNode;

                    int id = parseIntOrDefault(getElementTextContent(deliveryNoteElement, "ID"), -1);
                    int orderConfirmationId = parseIntOrDefault(getElementTextContent(deliveryNoteElement, "OrderConfirmationID"), -1);
                    OrderConfirmation deliveryNoteOrderConfirmation = orderConfirmations.stream().filter(oc -> oc.id == orderConfirmationId).findFirst().orElse(null);

                    String date = getElementTextContent(deliveryNoteElement, "Date");
                    String status = getElementTextContent(deliveryNoteElement, "Status");

                    if (deliveryNoteOrderConfirmation != null) {
                        deliveryNotes.add(new DeliveryNote(id, deliveryNoteOrderConfirmation, date, status));
                    }
                }
            }

            NodeList invoiceList = document.getElementsByTagName("Invoice");
            invoices.clear(); // Vor dem Laden die aktuelle Liste leeren

            for (int i = 0; i < invoiceList.getLength(); i++) {
                Node invoiceNode = invoiceList.item(i);

                if (invoiceNode != null && invoiceNode.getNodeType() == Node.ELEMENT_NODE) {
                    Element invoiceElement = (Element) invoiceNode;

                    int id = parseIntOrDefault(getElementTextContent(invoiceElement, "ID"), -1);
                    int deliveryNoteId = parseIntOrDefault(getElementTextContent(invoiceElement, "DeliveryNoteID"), -1);
                    DeliveryNote invoiceDeliveryNote = deliveryNotes.stream().filter(dn -> dn.id == deliveryNoteId).findFirst().orElse(null);

                    String date = getElementTextContent(invoiceElement, "Date");
                    String status = getElementTextContent(invoiceElement, "Status");

                    if (invoiceDeliveryNote != null) {
                        invoices.add(new Invoice(id, invoiceDeliveryNote, date, status));
                    }
                }
            }

            System.out.println("Daten erfolgreich geladen.");

        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private static String getElementTextContent(Element parentElement, String tagName) {
        NodeList nodeList = parentElement.getElementsByTagName(tagName);
        if (nodeList != null && nodeList.getLength() > 0) {
            Node node = nodeList.item(0);
            if (node != null) {
                return node.getTextContent();
            }
        }
        return "";
    }

    private static int parseIntOrDefault(String str, int defaultValue) {
        try {
            return Integer.parseInt(str);
        } catch (NumberFormatException e) {
            return defaultValue;
        }
    }

    private static double parseDoubleOrDefault(String str, double defaultValue) {
        try {
            return Double.parseDouble(str);
        } catch (NumberFormatException e) {
            return defaultValue;
        }
    }
    
    public static void deleteCustomer(int index) {
        if (index >= 0 && index < customers.size()) {
            customers.remove(index);
        }
    }

    public static void deleteArticle(int index) {
        if (index >= 0 && index < articles.size()) {
            articles.remove(index);
        }
    }

    public static void deleteOffer(int index) {
        if (index >= 0 && index < offers.size()) {
            offers.remove(index);
        }
    }

    public static void deleteOrderConfirmation(int index) {
        if (index >= 0 && index < orderConfirmations.size()) {
            orderConfirmations.remove(index);
        }
    }

    public static void deleteDeliveryNote(int index) {
        if (index >= 0 && index < deliveryNotes.size()) {
            deliveryNotes.remove(index);
        }
    }

    public static void deleteInvoice(int index) {
        if (index >= 0 && index < invoices.size()) {
            invoices.remove(index);
        }
    }



}
