import javax.swing.*;
import java.awt.*;
import java.util.ArrayList;
import java.util.List;

public class MainGUI {
    private JFrame frame;
    private JTextArea textArea;
    private JPanel mainPanel;
    private CardLayout cardLayout;

    public MainGUI() {
        initialize();
    }

    private void initialize() {
        frame = new JFrame("Fakturama");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setSize(800, 600);
        frame.setLayout(new BorderLayout());

        cardLayout = new CardLayout();
        mainPanel = new JPanel(cardLayout);
        frame.add(mainPanel, BorderLayout.CENTER);

        // Menüleiste
        JMenuBar menuBar = new JMenuBar();
        frame.setJMenuBar(menuBar);

        JMenu menu = new JMenu("Optionen");
        menuBar.add(menu);

        JMenuItem addCustomerItem = new JMenuItem("Kunde hinzufügen");
        menu.add(addCustomerItem);
        addCustomerItem.addActionListener(e -> showAddCustomerPanel());
        
        JMenuItem deleteCustomerItem = new JMenuItem("Kunde löschen");
        menu.add(deleteCustomerItem);
        deleteCustomerItem.addActionListener(e -> showDeleteCustomerPanel());

        JMenuItem addArticleItem = new JMenuItem("Artikel hinzufügen");
        menu.add(addArticleItem);
        addArticleItem.addActionListener(e -> showAddArticlePanel());
        
        JMenuItem deleteArticleItem = new JMenuItem("Artikel löschen");
        menu.add(deleteArticleItem);
        deleteArticleItem.addActionListener(e -> showDeleteArticlePanel());

        JMenuItem createOfferItem = new JMenuItem("Angebot erstellen");
        menu.add(createOfferItem);
        createOfferItem.addActionListener(e -> showCreateOfferPanel());
        
        JMenuItem deleteOfferItem = new JMenuItem("Angebot löschen");
        menu.add(deleteOfferItem);
        deleteOfferItem.addActionListener(e -> showDeleteOfferPanel());

        JMenuItem createOrderConfirmationItem = new JMenuItem("Auftragsbestätigung erstellen");
        menu.add(createOrderConfirmationItem);
        createOrderConfirmationItem.addActionListener(e -> showCreateOrderConfirmationPanel());
        
        JMenuItem deleteOrderConfirmationItem = new JMenuItem("Auftragsbestätigung löschen");
        menu.add(deleteOrderConfirmationItem);
        deleteOrderConfirmationItem.addActionListener(e -> showDeleteOrderConfirmationPanel());

        JMenuItem createDeliveryNoteItem = new JMenuItem("Lieferschein erstellen");
        menu.add(createDeliveryNoteItem);
        createDeliveryNoteItem.addActionListener(e -> showCreateDeliveryNotePanel());
        
        JMenuItem deleteDeliveryNoteItem = new JMenuItem("Lieferschein löschen");
        menu.add(deleteDeliveryNoteItem);
        deleteDeliveryNoteItem.addActionListener(e -> showDeleteDeliveryNotePanel());

        JMenuItem createInvoiceItem = new JMenuItem("Rechnung erstellen");
        menu.add(createInvoiceItem);
        createInvoiceItem.addActionListener(e -> showCreateInvoicePanel());
        
        JMenuItem deleteInvoiceItem = new JMenuItem("Rechnung löschen");
        menu.add(deleteInvoiceItem);
        deleteInvoiceItem.addActionListener(e -> showDeleteInvoicePanel());

        JMenuItem saveDataItem = new JMenuItem("Daten speichern");
        menu.add(saveDataItem);
        saveDataItem.addActionListener(e -> {
            Main.saveData();
            updateTextArea();
        });

        JMenuItem loadDataItem = new JMenuItem("Daten laden");
        menu.add(loadDataItem);
        loadDataItem.addActionListener(e -> {
            Main.loadData();
            updateTextArea();
        });

        JMenuItem exitItem = new JMenuItem("Beenden");
        menu.add(exitItem);
        exitItem.addActionListener(e -> System.exit(0));

        textArea = new JTextArea();
        textArea.setEditable(false);
        JScrollPane scrollPane = new JScrollPane(textArea);

        JPanel homePanel = new JPanel(new BorderLayout());
        homePanel.add(scrollPane, BorderLayout.CENTER);

        mainPanel.add(homePanel, "Home");
        cardLayout.show(mainPanel, "Home");

        frame.setVisible(true);
        updateTextArea();
    }

    private void showAddCustomerPanel() {
        JPanel panel = new JPanel(new GridLayout(6, 2));
        JLabel nameLabel = new JLabel("Name:");
        JTextField nameField = new JTextField();
        JLabel addressLabel = new JLabel("Adresse:");
        JTextField addressField = new JTextField();
        JLabel contactLabel = new JLabel("Ansprechpartner:");
        JTextField contactField = new JTextField();
        JLabel taxExemptLabel = new JLabel("Unter § 4 UStG:");
        JCheckBox taxExemptBox = new JCheckBox();
        JLabel smallBusinessLabel = new JLabel("Kleinunternehmer:");
        JCheckBox smallBusinessBox = new JCheckBox();

        JButton addButton = new JButton("Hinzufügen");
        addButton.setBackground(new Color(144, 238, 144)); // Hellgrün
        addButton.addActionListener(e -> {
            String name = nameField.getText();
            String address = addressField.getText();
            String contactPerson = contactField.getText();
            boolean taxExempt = taxExemptBox.isSelected();
            boolean smallBusiness = smallBusinessBox.isSelected();
            Main.customers.add(new Main.Customer(name, address, contactPerson, taxExempt, smallBusiness));
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        panel.add(nameLabel);
        panel.add(nameField);
        panel.add(addressLabel);
        panel.add(addressField);
        panel.add(contactLabel);
        panel.add(contactField);
        panel.add(taxExemptLabel);
        panel.add(taxExemptBox);
        panel.add(smallBusinessLabel);
        panel.add(smallBusinessBox);
        panel.add(backButton);
        panel.add(addButton);

        mainPanel.add(panel, "AddCustomer");
        cardLayout.show(mainPanel, "AddCustomer");
    }

    private void showAddArticlePanel() {
        JPanel panel = new JPanel(new GridLayout(6, 2));
        JLabel unitLabel = new JLabel("Einheit:");
        JTextField unitField = new JTextField();
        JLabel descriptionLabel = new JLabel("Bezeichnung:");
        JTextField descriptionField = new JTextField();
        JLabel netPriceLabel = new JLabel("Nettopreis:");
        JTextField netPriceField = new JTextField();
        JLabel vatRateLabel = new JLabel("Mehrwertsteuersatz:");
        JComboBox<String> vatRateBox = new JComboBox<>(new String[]{"19%", "7%"});

        JButton addButton = new JButton("Hinzufügen");
        addButton.setBackground(new Color(144, 238, 144)); // Hellgrün
        addButton.addActionListener(e -> {
            String unit = unitField.getText();
            String description = descriptionField.getText();
            double netPrice = Double.parseDouble(netPriceField.getText());
            double vatRate = vatRateBox.getSelectedIndex() == 0 ? 19.0 : 7.0;
            Main.articles.add(new Main.Article(unit, description, netPrice, vatRate));
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        panel.add(unitLabel);
        panel.add(unitField);
        panel.add(descriptionLabel);
        panel.add(descriptionField);
        panel.add(netPriceLabel);
        panel.add(netPriceField);
        panel.add(vatRateLabel);
        panel.add(vatRateBox);
        panel.add(backButton);
        panel.add(addButton);

        mainPanel.add(panel, "AddArticle");
        cardLayout.show(mainPanel, "AddArticle");
    }

    private void showCreateOfferPanel() {
        JPanel panel = new JPanel(new BorderLayout());

        JPanel formPanel = new JPanel(new GridLayout(2, 2));
        JLabel customerLabel = new JLabel("Kunde:");
        JComboBox<String> customerBox = new JComboBox<>();
        for (Main.Customer customer : Main.customers) {
            customerBox.addItem(customer.name);
        }
        formPanel.add(customerLabel);
        formPanel.add(customerBox);

        JLabel dateLabel = new JLabel("Datum:");
        JTextField dateField = new JTextField();
        formPanel.add(dateLabel);
        formPanel.add(dateField);

        panel.add(formPanel, BorderLayout.NORTH);

        JLabel articlesLabel = new JLabel("Artikel:");
        JList<String> articlesList = new JList<>(Main.articles.stream().map(a -> a.description).toArray(String[]::new));
        articlesList.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
        JScrollPane articlesScrollPane = new JScrollPane(articlesList);

        panel.add(articlesLabel, BorderLayout.CENTER);
        panel.add(articlesScrollPane, BorderLayout.CENTER);

        JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.RIGHT));
        JButton addButton = new JButton("Erstellen");
        addButton.setBackground(new Color(144, 238, 144)); // Hellgrün
        addButton.addActionListener(e -> {
            String customerName = (String) customerBox.getSelectedItem();
            Main.Customer customer = Main.customers.stream().filter(c -> c.name.equals(customerName)).findFirst().orElse(null);
            List<Main.Article> selectedArticles = new ArrayList<>();
            for (String articleDesc : articlesList.getSelectedValuesList()) {
                Main.Article article = Main.articles.stream().filter(a -> a.description.equals(articleDesc)).findFirst().orElse(null);
                selectedArticles.add(article);
            }
            String date = dateField.getText();
            Main.offers.add(new Main.Offer(Main.nextOfferId++, customer, selectedArticles, date, "Angebot erstellt"));
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        buttonPanel.add(backButton);
        buttonPanel.add(addButton);

        panel.add(buttonPanel, BorderLayout.SOUTH);

        mainPanel.add(panel, "CreateOffer");
        cardLayout.show(mainPanel, "CreateOffer");
    }

    private void showCreateOrderConfirmationPanel() {
        JPanel panel = new JPanel(new GridLayout(4, 2));
        JLabel offerLabel = new JLabel("Angebot:");
        JComboBox<String> offerBox = new JComboBox<>();
        for (Main.Offer offer : Main.offers) {
            offerBox.addItem("Angebot #" + offer.id + " - Kunde: " + offer.customer.name);
        }

        JLabel dateLabel = new JLabel("Datum:");
        JTextField dateField = new JTextField();

        JButton addButton = new JButton("Erstellen");
        addButton.setBackground(new Color(144, 238, 144)); // Hellgrün
        addButton.addActionListener(e -> {
            int offerIndex = offerBox.getSelectedIndex();
            Main.Offer selectedOffer = Main.offers.get(offerIndex);
            String date = dateField.getText();
            Main.orderConfirmations.add(new Main.OrderConfirmation(Main.nextOrderConfirmationId++, selectedOffer, date, "Auftragsbestätigung erstellt"));
            selectedOffer.status = "Auftragsbestätigung erstellt";
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        panel.add(offerLabel);
        panel.add(offerBox);
        panel.add(dateLabel);
        panel.add(dateField);
        panel.add(backButton);
        panel.add(addButton);

        mainPanel.add(panel, "CreateOrderConfirmation");
        cardLayout.show(mainPanel, "CreateOrderConfirmation");
    }

    private void showCreateDeliveryNotePanel() {
        JPanel panel = new JPanel(new GridLayout(4, 2));
        JLabel orderConfirmationLabel = new JLabel("Auftragsbestätigung:");
        JComboBox<String> orderConfirmationBox = new JComboBox<>();
        for (Main.OrderConfirmation orderConfirmation : Main.orderConfirmations) {
            orderConfirmationBox.addItem("Auftragsbestätigung #" + orderConfirmation.id + " - Kunde: " + orderConfirmation.offer.customer.name);
        }

        JLabel dateLabel = new JLabel("Datum:");
        JTextField dateField = new JTextField();

        JButton addButton = new JButton("Erstellen");
        addButton.setBackground(new Color(144, 238, 144)); // Hellgrün
        addButton.addActionListener(e -> {
            int orderConfirmationIndex = orderConfirmationBox.getSelectedIndex();
            Main.OrderConfirmation selectedOrderConfirmation = Main.orderConfirmations.get(orderConfirmationIndex);
            String date = dateField.getText();
            Main.deliveryNotes.add(new Main.DeliveryNote(Main.nextDeliveryNoteId++, selectedOrderConfirmation, date, "Lieferschein erstellt"));
            selectedOrderConfirmation.status = "Lieferschein erstellt";
            selectedOrderConfirmation.offer.status = "Lieferschein erstellt";
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        panel.add(orderConfirmationLabel);
        panel.add(orderConfirmationBox);
        panel.add(dateLabel);
        panel.add(dateField);
        panel.add(backButton);
        panel.add(addButton);

        mainPanel.add(panel, "CreateDeliveryNote");
        cardLayout.show(mainPanel, "CreateDeliveryNote");
    }

    private void showCreateInvoicePanel() {
        JPanel panel = new JPanel(new GridLayout(4, 2));
        JLabel deliveryNoteLabel = new JLabel("Lieferschein:");
        JComboBox<String> deliveryNoteBox = new JComboBox<>();
        for (Main.DeliveryNote deliveryNote : Main.deliveryNotes) {
            deliveryNoteBox.addItem("Lieferschein #" + deliveryNote.id + " - Kunde: " + deliveryNote.orderConfirmation.offer.customer.name);
        }

        JLabel dateLabel = new JLabel("Datum:");
        JTextField dateField = new JTextField();

        JButton addButton = new JButton("Erstellen");
        addButton.setBackground(new Color(144, 238, 144)); // Hellgrün
        addButton.addActionListener(e -> {
            int deliveryNoteIndex = deliveryNoteBox.getSelectedIndex();
            Main.DeliveryNote selectedDeliveryNote = Main.deliveryNotes.get(deliveryNoteIndex);
            String date = dateField.getText();
            Main.invoices.add(new Main.Invoice(Main.nextInvoiceId++, selectedDeliveryNote, date, "Rechnung erstellt"));
            selectedDeliveryNote.status = "Rechnung erstellt";
            selectedDeliveryNote.orderConfirmation.status = "Rechnung erstellt";
            selectedDeliveryNote.orderConfirmation.offer.status = "Rechnung erstellt";
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        panel.add(deliveryNoteLabel);
        panel.add(deliveryNoteBox);
        panel.add(dateLabel);
        panel.add(dateField);
        panel.add(backButton);
        panel.add(addButton);

        mainPanel.add(panel, "CreateInvoice");
        cardLayout.show(mainPanel, "CreateInvoice");
    }

    private void updateTextArea() {
        StringBuilder sb = new StringBuilder();
        sb.append("Kunden:\n");
        for (int i = 0; i < Main.customers.size(); i++) {
            Main.Customer customer = Main.customers.get(i);
            sb.append(i + 1).append(". ").append(customer.name).append(" - ").append(customer.address).append(" - ").append(customer.contactPerson).append(" - ").append(customer.taxExempt ? "§ 4 UStG" : "").append(" - ").append(customer.smallBusiness ? "Kleinunternehmer" : "").append("\n");
        }
        sb.append("\nArtikel:\n");
        for (int i = 0; i < Main.articles.size(); i++) {
            Main.Article article = Main.articles.get(i);
            sb.append(i + 1).append(". ").append(article.description).append(" - ").append(article.unit).append(" - ").append(article.netPrice).append(" € - ").append(article.vatRate).append(" %").append("\n");
        }
        sb.append("\nAngebote:\n");
        for (int i = 0; i < Main.offers.size(); i++) {
            Main.Offer offer = Main.offers.get(i);
            sb.append(i + 1).append(". Angebot #").append(offer.id).append(" - ").append(offer.customer.name).append(" - ").append(offer.date).append(" - ").append(offer.status).append("\n");
            for (Main.Article article : offer.articles) {
                sb.append("  ").append(article.description).append(" - ").append(article.unit).append(" - ").append(article.netPrice).append(" € - ").append(article.vatRate).append(" %").append("\n");
            }
        }
        sb.append("\nAuftragsbestätigungen:\n");
        for (int i = 0; i < Main.orderConfirmations.size(); i++) {
            Main.OrderConfirmation orderConfirmation = Main.orderConfirmations.get(i);
            sb.append(i + 1).append(". Auftragsbestätigung #").append(orderConfirmation.id).append(" - ").append(orderConfirmation.offer.customer.name).append(" - ").append(orderConfirmation.date).append(" - ").append(orderConfirmation.status).append("\n");
        }
        sb.append("\nLieferscheine:\n");
        for (int i = 0; i < Main.deliveryNotes.size(); i++) {
            Main.DeliveryNote deliveryNote = Main.deliveryNotes.get(i);
            sb.append(i + 1).append(". Lieferschein #").append(deliveryNote.id).append(" - ").append(deliveryNote.orderConfirmation.offer.customer.name).append(" - ").append(deliveryNote.date).append(" - ").append(deliveryNote.status).append("\n");
        }
        sb.append("\nRechnungen:\n");
        for (int i = 0; i < Main.invoices.size(); i++) {
            Main.Invoice invoice = Main.invoices.get(i);
            sb.append(i + 1).append(". Rechnung #").append(invoice.id).append(" - ").append(invoice.deliveryNote.orderConfirmation.offer.customer.name).append(" - ").append(invoice.date).append(" - ").append(invoice.status).append("\n");
        }
        textArea.setText(sb.toString());
    }
    
    private void showDeleteCustomerPanel() {
        JPanel panel = new JPanel(new GridLayout(3, 2));
        JLabel customerLabel = new JLabel("Kunde:");
        JComboBox<String> customerBox = new JComboBox<>();
        for (Main.Customer customer : Main.customers) {
            customerBox.addItem(customer.name);
        }

        JButton deleteButton = new JButton("Löschen");
        deleteButton.setBackground(new Color(255, 99, 71)); // Tomatenrot
        deleteButton.addActionListener(e -> {
            String customerName = (String) customerBox.getSelectedItem();
            Main.customers.removeIf(c -> c.name.equals(customerName));
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        panel.add(customerLabel);
        panel.add(customerBox);
        panel.add(backButton);
        panel.add(deleteButton);

        mainPanel.add(panel, "DeleteCustomer");
        cardLayout.show(mainPanel, "DeleteCustomer");
    }

    private void showDeleteArticlePanel() {
        JPanel panel = new JPanel(new GridLayout(3, 2));
        JLabel articleLabel = new JLabel("Artikel:");
        JComboBox<String> articleBox = new JComboBox<>();
        for (Main.Article article : Main.articles) {
            articleBox.addItem(article.description);
        }

        JButton deleteButton = new JButton("Löschen");
        deleteButton.setBackground(new Color(255, 99, 71)); // Tomatenrot
        deleteButton.addActionListener(e -> {
            String articleDescription = (String) articleBox.getSelectedItem();
            Main.articles.removeIf(a -> a.description.equals(articleDescription));
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        panel.add(articleLabel);
        panel.add(articleBox);
        panel.add(backButton);
        panel.add(deleteButton);

        mainPanel.add(panel, "DeleteArticle");
        cardLayout.show(mainPanel, "DeleteArticle");
    }

    private void showDeleteOfferPanel() {
        JPanel panel = new JPanel(new GridLayout(3, 2));
        JLabel offerLabel = new JLabel("Angebot:");
        JComboBox<String> offerBox = new JComboBox<>();
        for (Main.Offer offer : Main.offers) {
            offerBox.addItem("Angebot #" + offer.id + " - Kunde: " + offer.customer.name);
        }

        JButton deleteButton = new JButton("Löschen");
        deleteButton.setBackground(new Color(255, 99, 71)); // Tomatenrot
        deleteButton.addActionListener(e -> {
            String offerInfo = (String) offerBox.getSelectedItem();
            int offerId = Integer.parseInt(offerInfo.split(" ")[1].substring(1));
            Main.offers.removeIf(o -> o.id == offerId);
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        panel.add(offerLabel);
        panel.add(offerBox);
        panel.add(backButton);
        panel.add(deleteButton);

        mainPanel.add(panel, "DeleteOffer");
        cardLayout.show(mainPanel, "DeleteOffer");
    }

    private void showDeleteOrderConfirmationPanel() {
        JPanel panel = new JPanel(new GridLayout(3, 2));
        JLabel orderConfirmationLabel = new JLabel("Auftragsbestätigung:");
        JComboBox<String> orderConfirmationBox = new JComboBox<>();
        for (Main.OrderConfirmation orderConfirmation : Main.orderConfirmations) {
            orderConfirmationBox.addItem("Auftragsbestätigung #" + orderConfirmation.id + " - Kunde: " + orderConfirmation.offer.customer.name);
        }

        JButton deleteButton = new JButton("Löschen");
        deleteButton.setBackground(new Color(255, 99, 71)); // Tomatenrot
        deleteButton.addActionListener(e -> {
            String orderConfirmationInfo = (String) orderConfirmationBox.getSelectedItem();
            int orderConfirmationId = Integer.parseInt(orderConfirmationInfo.split(" ")[1].substring(1));
            Main.orderConfirmations.removeIf(oc -> oc.id == orderConfirmationId);
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        panel.add(orderConfirmationLabel);
        panel.add(orderConfirmationBox);
        panel.add(backButton);
        panel.add(deleteButton);

        mainPanel.add(panel, "DeleteOrderConfirmation");
        cardLayout.show(mainPanel, "DeleteOrderConfirmation");
    }

    private void showDeleteDeliveryNotePanel() {
        JPanel panel = new JPanel(new GridLayout(3, 2));
        JLabel deliveryNoteLabel = new JLabel("Lieferschein:");
        JComboBox<String> deliveryNoteBox = new JComboBox<>();
        for (Main.DeliveryNote deliveryNote : Main.deliveryNotes) {
            deliveryNoteBox.addItem("Lieferschein #" + deliveryNote.id + " - Kunde: " + deliveryNote.orderConfirmation.offer.customer.name);
        }

        JButton deleteButton = new JButton("Löschen");
        deleteButton.setBackground(new Color(255, 99, 71)); // Tomatenrot
        deleteButton.addActionListener(e -> {
            String deliveryNoteInfo = (String) deliveryNoteBox.getSelectedItem();
            int deliveryNoteId = Integer.parseInt(deliveryNoteInfo.split(" ")[1].substring(1));
            Main.deliveryNotes.removeIf(dn -> dn.id == deliveryNoteId);
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        panel.add(deliveryNoteLabel);
        panel.add(deliveryNoteBox);
        panel.add(backButton);
        panel.add(deleteButton);

        mainPanel.add(panel, "DeleteDeliveryNote");
        cardLayout.show(mainPanel, "DeleteDeliveryNote");
    }

    private void showDeleteInvoicePanel() {
        JPanel panel = new JPanel(new GridLayout(3, 2));
        JLabel invoiceLabel = new JLabel("Rechnung:");
        JComboBox<String> invoiceBox = new JComboBox<>();
        for (Main.Invoice invoice : Main.invoices) {
            invoiceBox.addItem("Rechnung #" + invoice.id + " - Kunde: " + invoice.deliveryNote.orderConfirmation.offer.customer.name);
        }

        JButton deleteButton = new JButton("Löschen");
        deleteButton.setBackground(new Color(255, 99, 71)); // Tomatenrot
        deleteButton.addActionListener(e -> {
            String invoiceInfo = (String) invoiceBox.getSelectedItem();
            int invoiceId = Integer.parseInt(invoiceInfo.split(" ")[1].substring(1));
            Main.invoices.removeIf(i -> i.id == invoiceId);
            updateTextArea();
            cardLayout.show(mainPanel, "Home");
        });

        JButton backButton = new JButton("Zurück");
        backButton.addActionListener(e -> cardLayout.show(mainPanel, "Home"));

        panel.add(invoiceLabel);
        panel.add(invoiceBox);
        panel.add(backButton);
        panel.add(deleteButton);

        mainPanel.add(panel, "DeleteInvoice");
        cardLayout.show(mainPanel, "DeleteInvoice");
    }


    public static void main(String[] args) {
        EventQueue.invokeLater(() -> {
            try {
                MainGUI window = new MainGUI();
                window.frame.setVisible(true);
            } catch (Exception e) {
                e.printStackTrace();
            }
        });
    }
}
