import static org.junit.jupiter.api.Assertions.*;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import java.util.ArrayList;
import java.util.List;

public class MainTest {

    @BeforeEach
    public void setUp() {
        Main.customers = new ArrayList<>();
        Main.articles = new ArrayList<>();
        Main.offers = new ArrayList<>();
        Main.orderConfirmations = new ArrayList<>();
        Main.deliveryNotes = new ArrayList<>();
        Main.invoices = new ArrayList<>();
    }

    @Test
    public void testAddCustomer() {
        Main.customers.add(new Main.Customer("Test Kunde", "Test Adresse", "Test Kontakt", true, false));
        assertEquals(1, Main.customers.size());
        assertEquals("Test Kunde", Main.customers.get(0).name);
        assertEquals("Test Adresse", Main.customers.get(0).address);
        assertEquals("Test Kontakt", Main.customers.get(0).contactPerson);
        assertTrue(Main.customers.get(0).taxExempt);
        assertFalse(Main.customers.get(0).smallBusiness);
    }

    @Test
    public void testAddArticle() {
        Main.articles.add(new Main.Article("Stück", "Test Artikel", 100.0, 19.0));
        assertEquals(1, Main.articles.size());
        assertEquals("Stück", Main.articles.get(0).unit);
        assertEquals("Test Artikel", Main.articles.get(0).description);
        assertEquals(100.0, Main.articles.get(0).netPrice);
        assertEquals(19.0, Main.articles.get(0).vatRate);
    }

    @Test
    public void testCreateOffer() {
        Main.Customer customer = new Main.Customer("Test Kunde", "Test Adresse", "Test Kontakt", true, false);
        Main.customers.add(customer);
        Main.Article article = new Main.Article("Stück", "Test Artikel", 100.0, 19.0);
        Main.articles.add(article);

        List<Main.Article> articles = new ArrayList<>();
        articles.add(article);
        Main.offers.add(new Main.Offer(1, customer, articles, "2024-06-30", "Angebot erstellt"));

        assertEquals(1, Main.offers.size());
        assertEquals(customer, Main.offers.get(0).customer);
        assertEquals(1, Main.offers.get(0).articles.size());
        assertEquals(article, Main.offers.get(0).articles.get(0));
        assertEquals("2024-06-30", Main.offers.get(0).date);
        assertEquals("Angebot erstellt", Main.offers.get(0).status);
    }

    @Test
    public void testCreateOrderConfirmation() {
        Main.Customer customer = new Main.Customer("Test Kunde", "Test Adresse", "Test Kontakt", true, false);
        Main.customers.add(customer);
        Main.Article article = new Main.Article("Stück", "Test Artikel", 100.0, 19.0);
        Main.articles.add(article);

        List<Main.Article> articles = new ArrayList<>();
        articles.add(article);
        Main.Offer offer = new Main.Offer(1, customer, articles, "2024-06-30", "Angebot erstellt");
        Main.offers.add(offer);

        Main.orderConfirmations.add(new Main.OrderConfirmation(1, offer, "2024-07-01", "Auftragsbestätigung erstellt"));

        assertEquals(1, Main.orderConfirmations.size());
        assertEquals(offer, Main.orderConfirmations.get(0).offer);
        assertEquals("2024-07-01", Main.orderConfirmations.get(0).date);
        assertEquals("Auftragsbestätigung erstellt", Main.orderConfirmations.get(0).status);
    }

    @Test
    public void testCreateDeliveryNote() {
        Main.Customer customer = new Main.Customer("Test Kunde", "Test Adresse", "Test Kontakt", true, false);
        Main.customers.add(customer);
        Main.Article article = new Main.Article("Stück", "Test Artikel", 100.0, 19.0);
        Main.articles.add(article);

        List<Main.Article> articles = new ArrayList<>();
        articles.add(article);
        Main.Offer offer = new Main.Offer(1, customer, articles, "2024-06-30", "Angebot erstellt");
        Main.offers.add(offer);

        Main.OrderConfirmation orderConfirmation = new Main.OrderConfirmation(1, offer, "2024-07-01", "Auftragsbestätigung erstellt");
        Main.orderConfirmations.add(orderConfirmation);

        Main.deliveryNotes.add(new Main.DeliveryNote(1, orderConfirmation, "2024-07-05", "Lieferschein erstellt"));

        assertEquals(1, Main.deliveryNotes.size());
        assertEquals(orderConfirmation, Main.deliveryNotes.get(0).orderConfirmation);
        assertEquals("2024-07-05", Main.deliveryNotes.get(0).date);
        assertEquals("Lieferschein erstellt", Main.deliveryNotes.get(0).status);
    }

    @Test
    public void testCreateInvoice() {
        Main.Customer customer = new Main.Customer("Test Kunde", "Test Adresse", "Test Kontakt", true, false);
        Main.customers.add(customer);
        Main.Article article = new Main.Article("Stück", "Test Artikel", 100.0, 19.0);
        Main.articles.add(article);

        List<Main.Article> articles = new ArrayList<>();
        articles.add(article);
        Main.Offer offer = new Main.Offer(1, customer, articles, "2024-06-30", "Angebot erstellt");
        Main.offers.add(offer);

        Main.OrderConfirmation orderConfirmation = new Main.OrderConfirmation(1, offer, "2024-07-01", "Auftragsbestätigung erstellt");
        Main.orderConfirmations.add(orderConfirmation);

        Main.DeliveryNote deliveryNote = new Main.DeliveryNote(1, orderConfirmation, "2024-07-05", "Lieferschein erstellt");
        Main.deliveryNotes.add(deliveryNote);

        Main.invoices.add(new Main.Invoice(1, deliveryNote, "2024-07-10", "Rechnung erstellt"));

        assertEquals(1, Main.invoices.size());
        assertEquals(deliveryNote, Main.invoices.get(0).deliveryNote);
        assertEquals("2024-07-10", Main.invoices.get(0).date);
        assertEquals("Rechnung erstellt", Main.invoices.get(0).status);
    }
}
